@@ -1,5 +1,5 @@
 from typing import Iterable
-from explainaboard.constants import TaskType
+from explainaboard.tasks import TaskType
 from explainaboard.processors.processor import Processor
 
 
